@@ -17,29 +17,30 @@
     #define JNICALL __stdcall
     
     #define __func__ __FUNCTION__
+	#if _MSC_VER < 1900
+		inline int vsnprintf(char* str, size_t size, const char* format, va_list ap)
+		{
+			int count = -1;
 
-    inline int vsnprintf(char* str, size_t size, const char* format, va_list ap)
-    {
-        int count = -1;
+			if (size != 0)
+				count = _vsnprintf_s(str, size, _TRUNCATE, format, ap);
+			if (count == -1)
+				count = _vscprintf(format, ap);
 
-        if (size != 0)
-            count = _vsnprintf_s(str, size, _TRUNCATE, format, ap);
-        if (count == -1)
-            count = _vscprintf(format, ap);
+			return count;
+		}
+		inline int snprintf(char* str, size_t size, const char* format, ...)
+		{
+			int count;
+			va_list ap;
 
-        return count;
-    }
-    inline int snprintf(char* str, size_t size, const char* format, ...)
-    {
-        int count;
-        va_list ap;
+			va_start(ap, format);
+			count = vsnprintf(str, size, format, ap);
+			va_end(ap);
 
-        va_start(ap, format);
-        count = vsnprintf(str, size, format, ap);
-        va_end(ap);
-
-        return count;
-    }
+			return count;
+		}
+	#endif
 #else
     #define JNIEXPORT 
     #define JNIIMPORT 
